qcacld-3.0: Rename pe_session member bssIdx

The Linux Coding Style doesn't allow mixed-case names so rename
bssIdx in struct pe_session to be in compliance.

Change-Id: Idf2df6cb4ca30e4fdae74b8fb39445bb878003c5
CRs-Fixed: 2459768
diff --git a/core/mac/inc/sir_api.h b/core/mac/inc/sir_api.h
index 08a5c00..56fbd37 100644
--- a/core/mac/inc/sir_api.h
+++ b/core/mac/inc/sir_api.h
@@ -1360,7 +1360,7 @@
 struct missed_beacon_ind {
 	uint16_t messageType;   /* eWNI_SME_MISSED_BEACON_IND */
 	uint16_t length;
-	uint8_t bssIdx;
+	uint8_t bss_idx;
 };
 
 /* / Definition for Set Context request */
@@ -1674,7 +1674,7 @@
 } tSmeIbssPeerInd, *tpSmeIbssPeerInd;
 
 struct ibss_peer_inactivity_ind {
-	uint8_t bssIdx;
+	uint8_t bss_idx;
 	uint8_t staIdx;
 	struct qdf_mac_addr peer_addr;
 };
@@ -2930,7 +2930,7 @@
 typedef struct sSirFirstBeaconTxCompleteInd {
 	uint16_t messageType;   /* eWNI_SME_MISSED_BEACON_IND */
 	uint16_t length;
-	uint8_t bssIdx;
+	uint8_t bss_idx;
 } tSirFirstBeaconTxCompleteInd, *tpSirFirstBeaconTxCompleteInd;
 
 typedef struct sSirSmeCSAIeTxCompleteRsp {
diff --git a/core/mac/src/pe/lim/lim_api.c b/core/mac/src/pe/lim/lim_api.c
index d7777f5..62431ee 100644
--- a/core/mac/src/pe/lim/lim_api.c
+++ b/core/mac/src/pe/lim/lim_api.c
@@ -1812,7 +1812,7 @@
 {
 	struct missed_beacon_ind *missed_beacon_ind = msg->bodyptr;
 	struct pe_session *pe_session =
-		pe_find_session_by_bss_idx(mac, missed_beacon_ind->bssIdx);
+		pe_find_session_by_bss_idx(mac, missed_beacon_ind->bss_idx);
 
 	if (!pe_session) {
 		pe_err("session does not exist for given BSSId");
@@ -2254,10 +2254,10 @@
 		return status;
 	}
 
-	add_bss_params->bssIdx = roam_sync_ind_ptr->roamed_vdev_id;
-	ft_session_ptr->bssIdx = (uint8_t) add_bss_params->bssIdx;
+	add_bss_params->bss_idx = roam_sync_ind_ptr->roamed_vdev_id;
+	ft_session_ptr->bss_idx = (uint8_t)add_bss_params->bss_idx;
 
-	curr_sta_ds->bssId = add_bss_params->bssIdx;
+	curr_sta_ds->bssId = add_bss_params->bss_idx;
 	curr_sta_ds->staIndex = add_bss_params->staContext.staIdx;
 	rrm_cache_mgmt_tx_power(mac_ctx, add_bss_params->txMgmtPower,
 				ft_session_ptr);
diff --git a/core/mac/src/pe/lim/lim_assoc_utils.c b/core/mac/src/pe/lim/lim_assoc_utils.c
index b0b5ecf..2471763 100644
--- a/core/mac/src/pe/lim/lim_assoc_utils.c
+++ b/core/mac/src/pe/lim/lim_assoc_utils.c
@@ -660,7 +660,7 @@
 	if (!pe_session->add_bss_failed) {
 		if (pe_session->limSmeState == eLIM_SME_JOIN_FAILURE_STATE) {
 			retCode =
-				lim_del_bss(mac, sta, pe_session->bssIdx,
+				lim_del_bss(mac, sta, pe_session->bss_idx,
 					    pe_session);
 		} else
 			retCode = lim_del_sta(mac,
@@ -3023,7 +3023,7 @@
 		return;
 	}
 
-	beacon_params.bssIdx = session_entry->bssIdx;
+	beacon_params.bss_idx = session_entry->bss_idx;
 	sta_ds = dph_lookup_hash_entry(mac_ctx, sta_addr, &aid,
 			 &session_entry->dph.dphHashTable);
 
@@ -3349,7 +3349,7 @@
  */
 
 QDF_STATUS
-lim_del_bss(struct mac_context *mac, tpDphHashNode sta, uint16_t bssIdx,
+lim_del_bss(struct mac_context *mac, tpDphHashNode sta, uint16_t bss_idx,
 	    struct pe_session *pe_session)
 {
 	tpDeleteBssParams pDelBssParams = NULL;
@@ -3365,11 +3365,11 @@
 	/* DPH was storing the AssocID in staID field, */
 	/* staID is actually assigned by HAL when AddSTA message is sent. */
 	if (sta) {
-		pDelBssParams->bssIdx = sta->bssId;
+		pDelBssParams->bss_idx = sta->bssId;
 		sta->valid = 0;
 		sta->mlmStaContext.mlmState = eLIM_MLM_WT_DEL_BSS_RSP_STATE;
 	} else
-		pDelBssParams->bssIdx = bssIdx;
+		pDelBssParams->bss_idx = bss_idx;
 	pe_session->limMlmState = eLIM_MLM_WT_DEL_BSS_RSP_STATE;
 	MTRACE(mac_trace
 		       (mac, TRACE_CODE_MLM_STATE, pe_session->peSessionId,
@@ -3389,7 +3389,7 @@
 	pDelBssParams->smesessionId = pe_session->smeSessionId;
 	pe_debug("Sessionid %d : Sending HAL_DELETE_BSS_REQ "
 			  "for bss idx: %X BSSID:" QDF_MAC_ADDR_STR,
-		       pDelBssParams->sessionId, pDelBssParams->bssIdx,
+		       pDelBssParams->sessionId, pDelBssParams->bss_idx,
 		       QDF_MAC_ADDR_ARRAY(pe_session->bssId));
 	/* we need to defer the message until we get the response back from HAL. */
 	SET_LIM_PROCESS_DEFD_MESGS(mac, false);
diff --git a/core/mac/src/pe/lim/lim_ibss_peer_mgmt.c b/core/mac/src/pe/lim/lim_ibss_peer_mgmt.c
index 2ebc0c6..7aaeab1 100644
--- a/core/mac/src/pe/lim/lim_ibss_peer_mgmt.c
+++ b/core/mac/src/pe/lim/lim_ibss_peer_mgmt.c
@@ -602,9 +602,9 @@
 			session->limMlmState);
 		return;
 	}
-	status = lim_del_bss(mac_ctx, NULL, session->bssIdx, session);
+	status = lim_del_bss(mac_ctx, NULL, session->bss_idx, session);
 	if (QDF_IS_STATUS_ERROR(status))
-		pe_err("delBss failed for bss: %d", session->bssIdx);
+		pe_err("delBss failed for bss: %d", session->bss_idx);
 }
 
 /**
@@ -964,8 +964,8 @@
 					pe_debug("---> Update Beacon Params");
 					sch_set_fixed_beacon_fields(mac,
 								    pe_session);
-					beaconParams.bssIdx =
-						pe_session->bssIdx;
+					beaconParams.bss_idx =
+						pe_session->bss_idx;
 					lim_send_beacon_params(mac, &beaconParams,
 							       pe_session);
 				}
@@ -1186,7 +1186,7 @@
 		return QDF_STATUS_E_FAILURE;
 	}
 
-	sta->bssId = pAddStaParams->bssIdx;
+	sta->bssId = pAddStaParams->bss_idx;
 	sta->staIndex = pAddStaParams->staIdx;
 	sta->valid = 1;
 	sta->mlmStaContext.mlmState = eLIM_MLM_LINK_ESTABLISHED_STATE;
@@ -1217,7 +1217,7 @@
 
 	if (pDelBss->status != QDF_STATUS_SUCCESS) {
 		pe_err("IBSS: DEL_BSS_RSP(coalesce) error: %x Bss: %d",
-			pDelBss->status, pDelBss->bssIdx);
+			pDelBss->status, pDelBss->bss_idx);
 		goto end;
 	}
 
@@ -1299,7 +1299,7 @@
 
 	if (pDelBss->status != QDF_STATUS_SUCCESS) {
 		pe_err("IBSS: DEL_BSS_RSP error: %x Bss: %d",
-			       pDelBss->status, pDelBss->bssIdx);
+			       pDelBss->status, pDelBss->bss_idx);
 		rc = eSIR_SME_STOP_BSS_FAILURE;
 		goto end;
 	}
@@ -1514,7 +1514,7 @@
 		if (beaconParams.paramChangeBitmap) {
 			pe_err("beaconParams.paramChangeBitmap=1 ---> Update Beacon Params");
 			sch_set_fixed_beacon_fields(mac, pe_session);
-			beaconParams.bssIdx = pe_session->bssIdx;
+			beaconParams.bss_idx = pe_session->bss_idx;
 			lim_send_beacon_params(mac, &beaconParams, pe_session);
 		}
 	} else
diff --git a/core/mac/src/pe/lim/lim_process_message_queue.c b/core/mac/src/pe/lim/lim_process_message_queue.c
index 4543277..6d39a23 100644
--- a/core/mac/src/pe/lim/lim_process_message_queue.c
+++ b/core/mac/src/pe/lim/lim_process_message_queue.c
@@ -1964,7 +1964,7 @@
 			if (wlan_reg_get_channel_state(mac_ctx->pdev,
 					session_entry->currentOperChannel)
 					!= CHANNEL_STATE_DFS) {
-				beacon_params.bssIdx = session_entry->bssIdx;
+				beacon_params.bss_idx = session_entry->bss_idx;
 				beacon_params.beaconInterval =
 					session_entry->beaconParams.beaconInterval;
 				beacon_params.paramChangeBitmap |=
diff --git a/core/mac/src/pe/lim/lim_process_mlm_host_roam.c b/core/mac/src/pe/lim/lim_process_mlm_host_roam.c
index 7605239..7ce4c35 100644
--- a/core/mac/src/pe/lim/lim_process_mlm_host_roam.c
+++ b/core/mac/src/pe/lim/lim_process_mlm_host_roam.c
@@ -472,10 +472,10 @@
 	pe_debug("Set the mlm state: %d session: %d",
 		       pe_session->limMlmState, pe_session->peSessionId);
 
-	pe_session->bssIdx = (uint8_t) pAddBssParams->bssIdx;
+	pe_session->bss_idx = (uint8_t)pAddBssParams->bss_idx;
 
 	/* Success, handle below */
-	sta->bssId = pAddBssParams->bssIdx;
+	sta->bssId = pAddBssParams->bss_idx;
 	/* STA Index(genr by HAL) for the BSS entry is stored here */
 	sta->staIndex = pAddBssParams->staContext.staIdx;
 
diff --git a/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c b/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c
index 9a09c80..cf61141 100644
--- a/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c
+++ b/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c
@@ -1618,7 +1618,7 @@
 	}
 	if (QDF_STATUS_SUCCESS == pDelBssParams->status) {
 		pe_debug("STA received the DEL_BSS_RSP for BSSID: %X",
-			       pDelBssParams->bssIdx);
+			       pDelBssParams->bss_idx);
 		if (lim_set_link_state
 			    (mac, eSIR_LINK_IDLE_STATE, pe_session->bssId,
 			    pe_session->selfMacAddr, NULL,
@@ -1706,7 +1706,7 @@
 	}
 	if (pDelBss->status != QDF_STATUS_SUCCESS) {
 		pe_err("BSS: DEL_BSS_RSP error (%x) Bss %d",
-			pDelBss->status, pDelBss->bssIdx);
+			pDelBss->status, pDelBss->bss_idx);
 		rc = eSIR_SME_STOP_BSS_FAILURE;
 		goto end;
 	}
@@ -1983,7 +1983,7 @@
 				       pe_session);
 		goto end;
 	}
-	sta->bssId = pAddStaParams->bssIdx;
+	sta->bssId = pAddStaParams->bss_idx;
 	sta->staIndex = pAddStaParams->staIdx;
 	sta->nss = pAddStaParams->nss;
 	/* if the AssocRsp frame is not acknowledged, then keep alive timer will take care of the state */
@@ -2091,7 +2091,7 @@
 			pe_session->statypeForBss = STA_ENTRY_PEER; /* to know session created for self/peer */
 			limResetHBPktCount(pe_session);
 		}
-		pe_session->bssIdx = (uint8_t) pAddBssParams->bssIdx;
+		pe_session->bss_idx = (uint8_t)pAddBssParams->bss_idx;
 
 		pe_session->limSystemRole = eLIM_STA_IN_IBSS_ROLE;
 
@@ -2220,7 +2220,7 @@
 		 */
 		pe_session->limIbssActive = false;
 		limResetHBPktCount(pe_session);
-		pe_session->bssIdx = (uint8_t) pAddBssParams->bssIdx;
+		pe_session->bss_idx = (uint8_t)pAddBssParams->bss_idx;
 		pe_session->limSystemRole = eLIM_STA_IN_IBSS_ROLE;
 		pe_session->statypeForBss = STA_ENTRY_SELF;
 		sch_edca_profile_update(mac, pe_session);
@@ -2313,9 +2313,9 @@
 				pAddBssParams->staContext.staMac, LOGE);
 			goto joinFailure;
 		}
-		session_entry->bssIdx = (uint8_t) pAddBssParams->bssIdx;
+		session_entry->bss_idx = (uint8_t)pAddBssParams->bss_idx;
 		/* Success, handle below */
-		sta->bssId = pAddBssParams->bssIdx;
+		sta->bssId = pAddBssParams->bss_idx;
 		/* STA Index(genr by HAL) for the BSS entry is stored here */
 		sta->staIndex = pAddBssParams->staContext.staIdx;
 		/* Trigger Authentication with AP */
@@ -2467,10 +2467,10 @@
 			mlm_assoc_cnf.resultCode =
 				(tSirResultCodes) eSIR_SME_REFUSED;
 		} else {
-			session_entry->bssIdx =
-				(uint8_t) add_bss_params->bssIdx;
+			session_entry->bss_idx =
+				(uint8_t)add_bss_params->bss_idx;
 			/* Success, handle below */
-			sta_ds->bssId = add_bss_params->bssIdx;
+			sta_ds->bssId = add_bss_params->bss_idx;
 			/*
 			 * STA Index(genr by HAL) for the BSS
 			 * entry is stored here
diff --git a/core/mac/src/pe/lim/lim_process_sme_req_messages.c b/core/mac/src/pe/lim/lim_process_sme_req_messages.c
index 1d163cb..ece7a32 100644
--- a/core/mac/src/pe/lim/lim_process_sme_req_messages.c
+++ b/core/mac/src/pe/lim/lim_process_sme_req_messages.c
@@ -2817,7 +2817,7 @@
 
 	status = lim_del_bss(mac_ctx, sta_ds, 0, session);
 	if (QDF_IS_STATUS_ERROR(status))
-		pe_err("delBss failed for bss %d", session->bssIdx);
+		pe_err("delBss failed for bss %d", session->bss_idx);
 
 end:
 	return status;
@@ -2828,10 +2828,10 @@
 	struct mac_context *mac_ctx = session->mac_ctx;
 	QDF_STATUS status;
 
-	status = lim_del_bss(mac_ctx, NULL, session->bssIdx, session);
+	status = lim_del_bss(mac_ctx, NULL, session->bss_idx, session);
 
 	if (QDF_IS_STATUS_ERROR(status)) {
-		pe_err("delBss failed for bss %d", session->bssIdx);
+		pe_err("delBss failed for bss %d", session->bss_idx);
 		lim_send_stop_bss_failure_resp(mac_ctx, session);
 	}
 
@@ -3858,7 +3858,7 @@
 			/* Update beacon */
 			sch_set_fixed_beacon_fields(mac, pe_session);
 
-			beaconParams.bssIdx = pe_session->bssIdx;
+			beaconParams.bss_idx = pe_session->bss_idx;
 			/* Set change in beacon Interval */
 			beaconParams.beaconInterval =
 				pChangeBIParams->beaconInterval;
diff --git a/core/mac/src/pe/lim/lim_process_tdls.c b/core/mac/src/pe/lim/lim_process_tdls.c
index 9a1d474..eb8f375 100644
--- a/core/mac/src/pe/lim/lim_process_tdls.c
+++ b/core/mac/src/pe/lim/lim_process_tdls.c
@@ -2728,7 +2728,7 @@
 		goto add_sta_error;
 	}
 
-	sta->bssId = pAddStaParams->bssIdx;
+	sta->bssId = pAddStaParams->bss_idx;
 	sta->staIndex = pAddStaParams->staIdx;
 	sta->mlmStaContext.mlmState = eLIM_MLM_LINK_ESTABLISHED_STATE;
 	sta->valid = 1;
diff --git a/core/mac/src/pe/lim/lim_security_utils.c b/core/mac/src/pe/lim/lim_security_utils.c
index 4da4c92..6f4b20d 100644
--- a/core/mac/src/pe/lim/lim_security_utils.c
+++ b/core/mac/src/pe/lim/lim_security_utils.c
@@ -800,7 +800,7 @@
 	}
 
 	/* Update the WMA_SET_BSSKEY_REQ parameters */
-	pSetBssKeyParams->bssIdx = pe_session->bssIdx;
+	pSetBssKeyParams->bss_idx = pe_session->bss_idx;
 	pSetBssKeyParams->encType = pMlmSetKeysReq->edType;
 
 	pSetBssKeyParams->singleTidRc =
diff --git a/core/mac/src/pe/lim/lim_send_management_frames.c b/core/mac/src/pe/lim/lim_send_management_frames.c
index eef1e28..9879f40 100644
--- a/core/mac/src/pe/lim/lim_send_management_frames.c
+++ b/core/mac/src/pe/lim/lim_send_management_frames.c
@@ -1226,7 +1226,7 @@
 	 */
 	populate_dot11f_capabilities(mac_ctx, &frm.Capabilities, pe_session);
 
-	beacon_params.bssIdx = pe_session->bssIdx;
+	beacon_params.bss_idx = pe_session->bss_idx;
 
 	/* Send message to HAL about beacon parameter change. */
 	if ((false == mac_ctx->sap.SapDfsInfo.is_dfs_cac_timer_running)
diff --git a/core/mac/src/pe/lim/lim_send_messages.c b/core/mac/src/pe/lim/lim_send_messages.c
index 0bced6f..6c5ae73 100644
--- a/core/mac/src/pe/lim/lim_send_messages.c
+++ b/core/mac/src/pe/lim/lim_send_messages.c
@@ -226,7 +226,7 @@
  */
 QDF_STATUS lim_send_edca_params(struct mac_context *mac,
 				   tSirMacEdcaParamRecord *pUpdatedEdcaParams,
-				   uint16_t bssIdx, bool mu_edca)
+				   uint16_t bss_idx, bool mu_edca)
 {
 	tEdcaParams *pEdcaParams = NULL;
 	QDF_STATUS retCode = QDF_STATUS_SUCCESS;
@@ -235,7 +235,7 @@
 	pEdcaParams = qdf_mem_malloc(sizeof(tEdcaParams));
 	if (!pEdcaParams)
 		return QDF_STATUS_E_NOMEM;
-	pEdcaParams->bssIdx = bssIdx;
+	pEdcaParams->bss_idx = bss_idx;
 	pEdcaParams->acbe = pUpdatedEdcaParams[QCA_WLAN_AC_BE];
 	pEdcaParams->acbk = pUpdatedEdcaParams[QCA_WLAN_AC_BK];
 	pEdcaParams->acvi = pUpdatedEdcaParams[QCA_WLAN_AC_VI];
@@ -603,8 +603,8 @@
 	if (!ht40_obss_scanind)
 		return QDF_STATUS_E_FAILURE;
 	QDF_TRACE(QDF_MODULE_ID_PE, QDF_TRACE_LEVEL_ERROR,
-		"OBSS Scan Indication bssIdx- %d staId %d",
-		session->bssIdx, session->staId);
+		"OBSS Scan Indication bss_idx- %d staId %d",
+		session->bss_idx, session->staId);
 
 	ht40_obss_scanind->cmd = HT40_OBSS_SCAN_PARAM_START;
 	ht40_obss_scanind->scan_type = eSIR_ACTIVE_SCAN;
@@ -644,7 +644,7 @@
 	ht40_obss_scanind->channel_count = channel24gnum;
 	/* FW API requests BSS IDX */
 	ht40_obss_scanind->self_sta_idx = session->staId;
-	ht40_obss_scanind->bss_id = session->bssIdx;
+	ht40_obss_scanind->bss_id = session->bss_idx;
 	ht40_obss_scanind->fortymhz_intolerent = 0;
 	ht40_obss_scanind->iefield_len = 0;
 	msg.type = WMA_HT40_OBSS_SCAN_IND;
diff --git a/core/mac/src/pe/lim/lim_send_messages.h b/core/mac/src/pe/lim/lim_send_messages.h
index 96d384f..5284229 100644
--- a/core/mac/src/pe/lim/lim_send_messages.h
+++ b/core/mac/src/pe/lim/lim_send_messages.h
@@ -65,7 +65,7 @@
 
 QDF_STATUS lim_send_edca_params(struct mac_context *mac,
 				   tSirMacEdcaParamRecord *pUpdatedEdcaParams,
-				   uint16_t bssIdx, bool mu_edca);
+				   uint16_t bss_idx, bool mu_edca);
 QDF_STATUS lim_set_link_state(struct mac_context *mac, tSirLinkState state,
 				 tSirMacAddr bssId, tSirMacAddr selfMac,
 				 tpSetLinkStateCallback callback,
diff --git a/core/mac/src/pe/lim/lim_send_sme_rsp_messages.c b/core/mac/src/pe/lim/lim_send_sme_rsp_messages.c
index c110918..a657473 100644
--- a/core/mac/src/pe/lim/lim_send_sme_rsp_messages.c
+++ b/core/mac/src/pe/lim/lim_send_sme_rsp_messages.c
@@ -2132,7 +2132,7 @@
 	tpSirFirstBeaconTxCompleteInd bcn_ind =
 		(tSirFirstBeaconTxCompleteInd *) event;
 
-	session = pe_find_session_by_bss_idx(mac_ctx, bcn_ind->bssIdx);
+	session = pe_find_session_by_bss_idx(mac_ctx, bcn_ind->bss_idx);
 	if (!session) {
 		pe_err("Session Does not exist for given session id");
 		return;
diff --git a/core/mac/src/pe/lim/lim_session.c b/core/mac/src/pe/lim/lim_session.c
index da79557..4030e02 100644
--- a/core/mac/src/pe/lim/lim_session.c
+++ b/core/mac/src/pe/lim/lim_session.c
@@ -228,7 +228,7 @@
 		pe_debug("protection changed, update beacon template");
 		/* update beacon fix params and send update to FW */
 		qdf_mem_zero(&beacon_params, sizeof(tUpdateBeaconParams));
-		beacon_params.bssIdx = pe_session_entry->bssIdx;
+		beacon_params.bss_idx = pe_session_entry->bss_idx;
 		beacon_params.fShortPreamble =
 				pe_session_entry->beaconParams.fShortPreamble;
 		beacon_params.beaconInterval =
@@ -733,28 +733,28 @@
 
 }
 
-/*--------------------------------------------------------------------------
-   \brief pe_find_session_by_bss_idx() - looks up the PE session given the bssIdx.
-
-   This function returns the session context  if the session
-   corresponding to the given bssIdx is found in the PE session table.
-   \param mac                   - pointer to global adapter context
-   \param bssIdx                   - bss index of the session
-   \return struct pe_session *         - pointer to the session context or NULL if session is not found.
-   \sa
-   --------------------------------------------------------------------------*/
-struct pe_session *pe_find_session_by_bss_idx(struct mac_context *mac, uint8_t bssIdx)
+/**
+ * pe_find_session_by_bss_idx() - looks up the PE session given the bss_idx.
+ *
+ * This function returns the session context  if the session
+ * corresponding to the given bss_idx is found in the PE session table.
+ * @mac:             pointer to global adapter context
+ * @bss_idx:         bss index of the session
+ *
+ * Return: pointer to the session context or NULL if session is not found.
+ */
+struct pe_session *pe_find_session_by_bss_idx(struct mac_context *mac,
+					      uint8_t bss_idx)
 {
 	uint8_t i;
 
 	for (i = 0; i < mac->lim.maxBssId; i++) {
 		/* If BSSID matches return corresponding tables address */
-		if ((mac->lim.gpSession[i].valid)
-		    && (mac->lim.gpSession[i].bssIdx == bssIdx)) {
+		if ((mac->lim.gpSession[i].valid) &&
+		    (mac->lim.gpSession[i].bss_idx == bss_idx))
 			return &mac->lim.gpSession[i];
-		}
 	}
-	pe_debug("Session lookup fails for bssIdx: %d", bssIdx);
+	pe_debug("Session lookup fails for bss_idx: %d", bss_idx);
 	return NULL;
 }
 
@@ -847,7 +847,7 @@
 
 	pe_debug("Trying to delete PE session: %d Opmode: %d BssIdx: %d BSSID: "QDF_MAC_ADDR_STR,
 		session->peSessionId, session->operMode,
-		session->bssIdx,
+		session->bss_idx,
 		QDF_MAC_ADDR_ARRAY(session->bssId));
 
 	lim_reset_bcn_probe_filter(mac_ctx, session);
diff --git a/core/mac/src/pe/lim/lim_utils.h b/core/mac/src/pe/lim/lim_utils.h
index 533d39e..6b97633 100644
--- a/core/mac/src/pe/lim/lim_utils.h
+++ b/core/mac/src/pe/lim/lim_utils.h
@@ -281,7 +281,7 @@
 		struct pe_session *pe_session);
 void lim_update_sta_run_time_ht_switch_chnl_params(struct mac_context *mac,
 		tDot11fIEHTInfo *pHTInfo,
-		uint8_t bssIdx,
+		uint8_t bss_idx,
 		struct pe_session *pe_session);
 /* Print MAC address utility function */
 void lim_print_mac_addr(struct mac_context *, tSirMacAddr, uint8_t);
diff --git a/core/mac/src/pe/nan/nan_datapath.c b/core/mac/src/pe/nan/nan_datapath.c
index 289c836..308a189 100644
--- a/core/mac/src/pe/nan/nan_datapath.c
+++ b/core/mac/src/pe/nan/nan_datapath.c
@@ -363,7 +363,7 @@
 		MTRACE(mac_trace(mac_ctx, TRACE_CODE_MLM_STATE,
 			session_entry->peSessionId,
 			session_entry->limMlmState));
-		session_entry->bssIdx = (uint8_t) add_bss_params->bssIdx;
+		session_entry->bss_idx = (uint8_t)add_bss_params->bss_idx;
 		session_entry->limSystemRole = eLIM_NDI_ROLE;
 		session_entry->statypeForBss = STA_ENTRY_SELF;
 		session_entry->staId = add_bss_params->staContext.staIdx;
@@ -414,7 +414,7 @@
 
 	if (del_bss->status != QDF_STATUS_SUCCESS) {
 		pe_err("NDI: DEL_BSS_RSP error (%x) Bss %d",
-			del_bss->status, del_bss->bssIdx);
+			del_bss->status, del_bss->bss_idx);
 		rc = eSIR_SME_STOP_BSS_FAILURE;
 		goto end;
 	}
@@ -523,7 +523,7 @@
 		qdf_mem_free(add_sta_rsp);
 		return;
 	}
-	sta_ds->bssId = add_sta_rsp->bssIdx;
+	sta_ds->bssId = add_sta_rsp->bss_idx;
 	sta_ds->staIndex = add_sta_rsp->staIdx;
 	sta_ds->valid = 1;
 	sta_ds->mlmStaContext.mlmState = eLIM_MLM_LINK_ESTABLISHED_STATE;
diff --git a/core/mac/src/pe/sch/sch_beacon_process.c b/core/mac/src/pe/sch/sch_beacon_process.c
index 02abe9b..e715d71 100644
--- a/core/mac/src/pe/sch/sch_beacon_process.c
+++ b/core/mac/src/pe/sch/sch_beacon_process.c
@@ -323,7 +323,7 @@
  * @bcn:            beacon struct
  * @rx_pkt_info:    received packet info
  * @session:        pe session pointer
- * @bssIdx:         bss index
+ * @bss_idx:         bss index
  * @beaconParams:   update beacon params
  * @sendProbeReq:   out flag to indicate if probe rsp is to be sent
  * @pMh:            mac header
@@ -336,7 +336,7 @@
 sch_bcn_process_sta(struct mac_context *mac_ctx,
 			       tpSchBeaconStruct bcn,
 			       uint8_t *rx_pkt_info,
-			       struct pe_session *session, uint8_t *bssIdx,
+			       struct pe_session *session, uint8_t *bss_idx,
 			       tUpdateBeaconParams *beaconParams,
 			       uint8_t *sendProbeReq, tpSirMacMgmtHdr pMh)
 {
@@ -370,11 +370,11 @@
 	}
 
 	lim_detect_change_in_ap_capabilities(mac_ctx, bcn, session);
-	if (lim_get_sta_hash_bssidx(mac_ctx, DPH_STA_HASH_INDEX_PEER, bssIdx,
+	if (lim_get_sta_hash_bssidx(mac_ctx, DPH_STA_HASH_INDEX_PEER, bss_idx,
 				    session) != QDF_STATUS_SUCCESS)
 		return false;
 
-	beaconParams->bssIdx = *bssIdx;
+	beaconParams->bss_idx = *bss_idx;
 	qdf_mem_copy((uint8_t *) &session->lastBeaconTimeStamp,
 			(uint8_t *) bcn->timeStamp, sizeof(uint64_t));
 	session->currentBssBeaconCnt++;
@@ -702,7 +702,7 @@
  * @bcn:            beacon struct
  * @rx_pkt_info:    received packet info
  * @session:        pe session pointer
- * @bssIdx:         bss index
+ * @bss_idx:         bss index
  * @beaconParams:   update beacon params
  * @sendProbeReq:   out flag to indicate if probe rsp is to be sent
  * @pMh:            mac header
@@ -715,7 +715,8 @@
 sch_bcn_process_sta_ibss(struct mac_context *mac_ctx,
 				    tpSchBeaconStruct bcn,
 				    uint8_t *rx_pkt_info,
-				    struct pe_session *session, uint8_t *bssIdx,
+				    struct pe_session *session,
+				    uint8_t *bss_idx,
 				    tUpdateBeaconParams *beaconParams,
 				    uint8_t *sendProbeReq, tpSirMacMgmtHdr pMh)
 {
@@ -812,7 +813,7 @@
 					     uint8_t *rx_pkt_info,
 					     struct pe_session *session)
 {
-	uint8_t bssIdx = 0;
+	uint8_t bss_idx = 0;
 	tUpdateBeaconParams beaconParams;
 	uint8_t sendProbeReq = false;
 	tpSirMacMgmtHdr pMh = WMA_GET_RX_MAC_HEADER(rx_pkt_info);
@@ -826,7 +827,7 @@
 		lim_handle_ibss_coalescing(mac_ctx, bcn, rx_pkt_info, session);
 	} else if (LIM_IS_STA_ROLE(session)) {
 		if (false == sch_bcn_process_sta(mac_ctx, bcn,
-				rx_pkt_info, session, &bssIdx,
+				rx_pkt_info, session, &bss_idx,
 				&beaconParams, &sendProbeReq, pMh))
 			return;
 	}
@@ -839,7 +840,7 @@
 	   bcn->VHTOperation.present)) && session->htCapability &&
 	   bcn->HTInfo.present && !LIM_IS_IBSS_ROLE(session))
 		lim_update_sta_run_time_ht_switch_chnl_params(mac_ctx,
-						&bcn->HTInfo, bssIdx, session);
+						&bcn->HTInfo, bss_idx, session);
 
 	if ((LIM_IS_STA_ROLE(session) && !wma_is_csa_offload_enabled())
 	    || LIM_IS_IBSS_ROLE(session)) {
@@ -864,7 +865,7 @@
 	if (LIM_IS_STA_ROLE(session)
 	    || LIM_IS_IBSS_ROLE(session))
 		sch_bcn_process_sta_ibss(mac_ctx, bcn,
-					rx_pkt_info, session, &bssIdx,
+					rx_pkt_info, session, &bss_idx,
 					&beaconParams, &sendProbeReq, pMh);
 	/* Obtain the Max Tx power for the current regulatory  */
 	regMax = lim_get_regulatory_max_transmit_power(
@@ -1059,7 +1060,7 @@
 	qdf_mem_zero(&bcn_prm, sizeof(tUpdateBeaconParams));
 	bcn_prm.paramChangeBitmap = 0;
 
-	bcn_prm.bssIdx = ap_session->bssIdx;
+	bcn_prm.bss_idx = ap_session->bss_idx;
 
 	if (!ap_session->is_session_obss_color_collision_det_enabled)
 		sch_check_bss_color_ie(mac_ctx, ap_session,
diff --git a/core/mac/src/pe/sch/sch_message.c b/core/mac/src/pe/sch/sch_message.c
index 02a9806..3a9b571 100644
--- a/core/mac/src/pe/sch/sch_message.c
+++ b/core/mac/src/pe/sch/sch_message.c
@@ -360,7 +360,7 @@
 
 	/* For AP, the bssID is stored in LIM Global context. */
 	lim_send_edca_params(mac, pe_session->gLimEdcaParams,
-			     pe_session->bssIdx, false);
+			     pe_session->bss_idx, false);
 }
 
 /**
diff --git a/core/wma/src/wma_dev_if.c b/core/wma/src/wma_dev_if.c
index 1b642db..a36011f 100644
--- a/core/wma/src/wma_dev_if.c
+++ b/core/wma/src/wma_dev_if.c
@@ -1155,7 +1155,7 @@
 			 __func__, bcn, bcn->buf);
 	}
 	add_bss->status = QDF_STATUS_SUCCESS;
-	add_bss->bssIdx = resp_event->vdev_id;
+	add_bss->bss_idx = resp_event->vdev_id;
 	add_bss->chainMask = resp_event->chain_mask;
 	if ((2 != resp_event->cfgd_rx_streams) ||
 		(2 != resp_event->cfgd_tx_streams)) {
@@ -4855,7 +4855,7 @@
 		add_bss->status = QDF_STATUS_E_FAILURE;
 	else
 		add_bss->status = QDF_STATUS_SUCCESS;
-	add_bss->bssIdx = add_bss->staContext.smesessionId;
+	add_bss->bss_idx = add_bss->staContext.smesessionId;
 	qdf_mem_copy(add_bss->staContext.staMac, add_bss->bssId,
 		     sizeof(add_bss->staContext.staMac));
 
diff --git a/core/wma/src/wma_mgmt.c b/core/wma/src/wma_mgmt.c
index b6a3085..69d7208 100644
--- a/core/wma/src/wma_mgmt.c
+++ b/core/wma/src/wma_mgmt.c
@@ -576,7 +576,7 @@
 
 	beacon_tx_complete_ind->messageType = WMA_DFS_BEACON_TX_SUCCESS_IND;
 	beacon_tx_complete_ind->length = sizeof(tSirFirstBeaconTxCompleteInd);
-	beacon_tx_complete_ind->bssIdx = resp_event->vdev_id;
+	beacon_tx_complete_ind->bss_idx = resp_event->vdev_id;
 
 	wma_send_msg(wma, WMA_DFS_BEACON_TX_SUCCESS_IND,
 		     (void *)beacon_tx_complete_ind, 0);
@@ -2658,7 +2658,7 @@
 	QDF_STATUS status;
 	void *soc = cds_get_context(QDF_MODULE_ID_SOC);
 
-	vdev_id = edca_params->bssIdx;
+	vdev_id = edca_params->bss_idx;
 	if (!wma_is_vdev_valid(vdev_id)) {
 		WMA_LOGE("%s: vdev id:%d is not active ", __func__, vdev_id);
 		goto fail;
@@ -3174,7 +3174,7 @@
 				     WLAN_CONTROL_PATH);
 	beacon_miss_ind->messageType = WMA_MISSED_BEACON_IND;
 	beacon_miss_ind->length = sizeof(*beacon_miss_ind);
-	beacon_miss_ind->bssIdx = vdev_id;
+	beacon_miss_ind->bss_idx = vdev_id;
 
 	wma_send_msg(wma, WMA_MISSED_BEACON_IND, beacon_miss_ind, 0);
 	if (!wmi_service_enabled(wma->wmi_handle,
diff --git a/core/wma/src/wma_utils.c b/core/wma/src/wma_utils.c
index a1bdcf3..34d4dc6 100644
--- a/core/wma/src/wma_utils.c
+++ b/core/wma/src/wma_utils.c
@@ -4831,7 +4831,7 @@
 		WMA_LOGE("%s wma handle is NULL", __func__);
 		return;
 	}
-	wma_remove_peer(wma, add_bss_params->bssId, add_bss_params->bssIdx,
+	wma_remove_peer(wma, add_bss_params->bssId, add_bss_params->bss_idx,
 			peer, false);
 }
 
@@ -4900,7 +4900,7 @@
 					   tpAddBssParams add_bss)
 {
 	WMA_LOGD(FL("Sending add bss rsp to umac(vdev %d status %d)"),
-		 add_bss->bssIdx, add_bss->status);
+		 add_bss->bss_idx, add_bss->status);
 	wma_send_msg_high_priority(wma, WMA_ADD_BSS_RSP, (void *)add_bss, 0);
 
 	return QDF_STATUS_SUCCESS;
@@ -5026,9 +5026,9 @@
 	tp_wma_handle wma = cds_get_context(QDF_MODULE_ID_WMA);
 	tpAddBssParams bss_params = (tpAddBssParams)data;
 
-	if (wma_send_vdev_stop_to_fw(wma, bss_params->bssIdx))
+	if (wma_send_vdev_stop_to_fw(wma, bss_params->bss_idx))
 		WMA_LOGE(FL("Failed to send vdev stop for vdev id %d"),
-			 bss_params->bssIdx);
+			 bss_params->bss_idx);
 
 	wma_remove_peer_on_add_bss_failure(bss_params);
diff --git a/core/mac/src/pe/include/lim_session.h b/core/mac/src/pe/include/lim_session.h
index b489e34..d08971d 100644
--- a/core/mac/src/pe/include/lim_session.h
+++ b/core/mac/src/pe/include/lim_session.h
@@ -149,7 +149,7 @@
 	tSirMacAddr bssId;
 	tSirMacAddr selfMacAddr;
 	tSirMacSSid ssId;
-	uint8_t bssIdx;
+	uint8_t bss_idx;
 	uint8_t valid;
 	tLimMlmStates limMlmState;      /* MLM State */
 	tLimMlmStates limPrevMlmState;  /* Previous MLM State */
@@ -648,17 +648,18 @@
 				     uint8_t *sessionId);
 
 /**
  * pe_find_session_by_bss_idx() - looks up the PE session given the bssIdx.
  *
  * @mac:          pointer to global adapter context
  * @bssIdx:        bss index of the session
  *
  * This function returns the session context  if the session
  * corresponding to the given bssIdx is found in the PE session table.
  *
  * Return: pointer to the session context or NULL if session is not found.
  */
-struct pe_session *pe_find_session_by_bss_idx(struct mac_context *mac, uint8_t bssIdx);
+struct pe_session *pe_find_session_by_bss_idx(struct mac_context *mac,
+					      uint8_t bss_idx);
 
 /**
  * pe_find_session_by_peer_sta() - looks up the PE session given the Peer
@@ -648,17 +648,18 @@
 
 /**
- * pe_find_session_by_bss_idx() - looks up the PE session given the bssIdx.
+ * pe_find_session_by_bss_idx() - looks up the PE session given the bss_idx.
  *
  * @mac:          pointer to global adapter context
@@ -648,17 +648,18 @@
  *
  * @mac:          pointer to global adapter context
- * @bssIdx:        bss index of the session
+ * @bss_idx:        bss index of the session
  *
  * This function returns the session context  if the session
@@ -648,17 +648,18 @@
  *
  * This function returns the session context  if the session
- * corresponding to the given bssIdx is found in the PE session table.
+ * corresponding to the given bss_idx is found in the PE session table.
  *
  * Return: pointer to the session context or NULL if session is not found.
diff --git a/core/mac/src/pe/lim/lim_utils.c b/core/mac/src/pe/lim/lim_utils.c
index 2f0cef7..e236048 100644
--- a/core/mac/src/pe/lim/lim_utils.c
+++ b/core/mac/src/pe/lim/lim_utils.c
@@ -878,7 +878,7 @@
 		return;
 	}
 	qdf_mem_zero((uint8_t *) &beaconParams, sizeof(tUpdateBeaconParams));
-	beaconParams.bssIdx = pe_session->bssIdx;
+	beaconParams.bss_idx = pe_session->bss_idx;
 
 	beaconParams.paramChangeBitmap = 0;
 	/*
@@ -3926,14 +3926,14 @@
  * \param pRcvdHTInfo Pointer to HT Info IE obtained from a  Beacon or
  * Probe Response
  *
  * \param bssIdx BSS Index of the Bss to which Station is associated.
  *
  *
  */
 
 void lim_update_sta_run_time_ht_switch_chnl_params(struct mac_context *mac,
 						   tDot11fIEHTInfo *pHTInfo,
-						   uint8_t bssIdx,
+						   uint8_t bss_idx,
 						   struct pe_session *pe_session)
 {
 	/* If self capability is set to '20Mhz only', then do not change the CB mode. */
@@ -4674,7 +4674,7 @@
 		 * Failure detected
 		 */
 		pe_debug("Sending Probe for Session: %d",
-			psession_entry->bssIdx);
+			psession_entry->bss_idx);
 		lim_deactivate_and_change_timer(mac_ctx,
 			eLIM_PROBE_AFTER_HB_TIMER);
 		MTRACE(mac_trace(mac_ctx, TRACE_CODE_TIMER_ACTIVATE, 0,
@@ -3926,14 +3926,14 @@
  * Probe Response
  *
- * \param bssIdx BSS Index of the Bss to which Station is associated.
+ * \param bss_idx BSS Index of the Bss to which Station is associated.
  *
  *
diff --git a/core/wma/inc/wma_if.h b/core/wma/inc/wma_if.h
index cde3c93..335db5e 100644
--- a/core/wma/inc/wma_if.h
+++ b/core/wma/inc/wma_if.h
@@ -146,7 +146,7 @@
  * @supportedRates: legacy supported rates
  * @status: QDF status
  * @staIdx: station index
  * @bssIdx: BSSID of BSS to which the station is associated
  * @updateSta: pdate the existing STA entry, if this flag is set
  * @respReqd: A flag to indicate to HAL if the response message is required
  * @rmfEnabled: Robust Management Frame (RMF) enabled/disabled
@@ -241,10 +241,10 @@
 	/* BSSID of BSS to which the station is associated.
 	 * This should be filled back in by HAL, and sent back to LIM as part of
 	 * the response message, so LIM can cache it in the station entry of
 	 * hash table. When station is deleted, LIM will make use of this bssIdx
 	 * to delete BSS from hal tables and from softmac.
 	 */
-	uint8_t bssIdx;
+	uint8_t bss_idx;
 	uint8_t updateSta;
 	uint8_t respReqd;
 	uint8_t rmfEnabled;
@@ -394,7 +394,7 @@
  * @currentExtChannel: Current Extension Channel, if applicable
  * @staContext: sta context
  * @status: status
  * @bssIdx: BSS index allocated by HAL
  * @updateBss: update the existing BSS entry, if this flag is set
  * @ssId: Add BSSID info for rxp filter
  * @respReqd: send the response message to LIM only when this flag is set
@@ -445,7 +445,7 @@
 	uint8_t currentOperChannel;
 	tAddStaParams staContext;
 	QDF_STATUS status;
-	uint16_t bssIdx;
+	uint16_t bss_idx;
 	/* HAL should update the existing BSS entry, if this flag is set.
 	 * PE will set this flag in case of reassoc, where we want to resue the
 	 * the old bssID and still return success.
@@ -497,7 +497,7 @@
 
 /**
  * struct tDeleteBssParams - params required for del bss request
- * @bssIdx: BSSID
+ * @bss_idx: BSSID
  * @status: QDF status
  * @respReqd: response message to LIM only when this flag is set
  * @sessionId: PE session id
@@ -505,7 +505,7 @@
  * @smesessionId: sme session id
  */
 typedef struct {
-	uint8_t bssIdx;
+	uint8_t bss_idx;
 	QDF_STATUS status;
 	uint8_t respReqd;
 	uint8_t sessionId;
@@ -617,7 +617,7 @@
 
 /**
  * struct tSetBssKeyParams - BSS key parameters
- * @bssIdx: BSSID index
+ * @bss_idx: BSSID index
  * @encType: encryption Type
  * @numKeys: number of keys
  * @key: key data
@@ -628,7 +628,7 @@
  * @macaddr: MAC address of the peer
  */
 typedef struct {
-	uint8_t bssIdx;
+	uint8_t bss_idx;
 	tAniEdType encType;
 	uint8_t numKeys;
 	tSirKeys key[SIR_MAC_MAX_NUM_OF_DEFAULT_KEYS];
@@ -641,7 +641,7 @@
 
 /**
  * struct tUpdateBeaconParams - update beacon request parameters
- * @bssIdx: BSSID index
+ * @bss_idx: BSSID index
  * @fShortPreamble: shortPreamble mode
  * @fShortSlotTime: short Slot time
  * @beaconInterval: Beacon Interval
@@ -655,7 +655,7 @@
  * @smeSessionId: SME  session id
  */
 typedef struct {
-	uint8_t bssIdx;
+	uint8_t bss_idx;
 	uint8_t fShortPreamble;
 	uint8_t fShortSlotTime;
 	uint16_t beaconInterval;
@@ -810,7 +810,7 @@
 
 /**
  * struct tEdcaParams - EDCA parameters
- * @bssIdx: BSSID index
+ * @bss_idx: BSSID index
  * @acbe: best effort access category
  * @acbk: Background access category
  * @acvi: video access category
@@ -818,7 +818,7 @@
  * @mu_edca_params: flag to indicate MU EDCA
  */
 typedef struct {
-	uint16_t bssIdx;
+	uint16_t bss_idx;
 	tSirMacEdcaParamRecord acbe;
 	tSirMacEdcaParamRecord acbk;
 	tSirMacEdcaParamRecord acvi;
@@ -146,7 +146,7 @@
  * @status: QDF status
  * @staIdx: station index
- * @bssIdx: BSSID of BSS to which the station is associated
+ * @bss_idx: BSSID of BSS to which the station is associated
  * @updateSta: pdate the existing STA entry, if this flag is set
  * @respReqd: A flag to indicate to HAL if the response message is required
@@ -241,10 +241,10 @@
 	 * This should be filled back in by HAL, and sent back to LIM as part of
 	 * the response message, so LIM can cache it in the station entry of
-	 * hash table. When station is deleted, LIM will make use of this bssIdx
-	 * to delete BSS from hal tables and from softmac.
+	 * hash table. When station is deleted, LIM will make use of this
+	 * bss_idx to delete BSS from hal tables and from softmac.
 	 */
@@ -394,7 +394,7 @@
  * @staContext: sta context
  * @status: status
- * @bssIdx: BSS index allocated by HAL
+ * @bss_idx: BSS index allocated by HAL
  * @updateBss: update the existing BSS entry, if this flag is set
  * @ssId: Add BSSID info for rxp filter